// 
// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 

// Warning: This code was generated by a tool.
// 
// Changes to this file may cause incorrect behavior and will be lost if the
// code is regenerated.

using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.Azure;
using Microsoft.Azure.Management.OperationalInsights.Models;

namespace Microsoft.Azure.Management.OperationalInsights
{
    /// <summary>
    /// Operations for managing storage insights.
    /// </summary>
    public partial interface IStorageInsightOperations
    {
        /// <summary>
        /// Create or update a storage insight.
        /// </summary>
        /// <param name='resourceGroupName'>
        /// The resource group name of the storage insight.
        /// </param>
        /// <param name='workspaceName'>
        /// The name of the parent workspace that will contain the storage
        /// insight
        /// </param>
        /// <param name='parameters'>
        /// The parameters required to create or update a storage insight.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// The create or update storage insight operation response.
        /// </returns>
        Task<StorageInsightCreateOrUpdateResponse> CreateOrUpdateAsync(string resourceGroupName, string workspaceName, StorageInsightCreateOrUpdateParameters parameters, CancellationToken cancellationToken);
        
        /// <summary>
        /// Deletes a storage insight instance.
        /// </summary>
        /// <param name='resourceGroupName'>
        /// The resource group name of the storage insight.
        /// </param>
        /// <param name='workspaceName'>
        /// The name of the workspace that contains the storage insight.
        /// </param>
        /// <param name='storageInsightName'>
        /// The name of the storage insight.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        Task<AzureOperationResponse> DeleteAsync(string resourceGroupName, string workspaceName, string storageInsightName, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets a storage insight instance.
        /// </summary>
        /// <param name='resourceGroupName'>
        /// The resource group name of the storage insight.
        /// </param>
        /// <param name='workspaceName'>
        /// The name of the workspace that contains the storage insight.
        /// </param>
        /// <param name='storageInsightName'>
        /// The name of the storage insight
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// The get storage insight operation response.
        /// </returns>
        Task<StorageInsightGetResponse> GetAsync(string resourceGroupName, string workspaceName, string storageInsightName, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets the first page of storage insight instances in a workspace
        /// with the link to the next page.
        /// </summary>
        /// <param name='resourceGroupName'>
        /// The resource group name of the storage insights.
        /// </param>
        /// <param name='workspaceName'>
        /// The workspace that contains the storage insights.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// The list storage insights operation response.
        /// </returns>
        Task<StorageInsightListResponse> ListInWorkspaceAsync(string resourceGroupName, string workspaceName, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets the next page of storage insight instances with the link to
        /// the next page.
        /// </summary>
        /// <param name='nextLink'>
        /// The url to the next storage insights page.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// The list storage insights operation response.
        /// </returns>
        Task<StorageInsightListResponse> ListNextAsync(string nextLink, CancellationToken cancellationToken);
    }
}
