// 
// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 

// Warning: This code was generated by a tool.
// 
// Changes to this file may cause incorrect behavior and will be lost if the
// code is regenerated.

using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.WindowsAzure.Management.ExpressRoute;
using Microsoft.WindowsAzure.Management.ExpressRoute.Models;

namespace Microsoft.WindowsAzure.Management.ExpressRoute
{
    /// <summary>
    /// The Express Route API provides programmatic access to the functionality
    /// needed by the customer to set up Dedicated Circuits and Dedicated
    /// Circuit Links. The Express Route Customer API is a REST API. All API
    /// operations are performed over SSL and mutually authenticated using
    /// X.509 v3 certificates.  (see
    /// http://msdn.microsoft.com/en-us/library/windowsazure/ee460799.aspx for
    /// more information)
    /// </summary>
    public static partial class DedicatedCircuitLinkOperationsExtensions
    {
        /// <summary>
        /// The New Dedicated Circuit Link operation creates a new dedicated
        /// circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static ExpressRouteOperationResponse BeginNew(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).BeginNewAsync(serviceKey, vnetName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The New Dedicated Circuit Link operation creates a new dedicated
        /// circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static Task<ExpressRouteOperationResponse> BeginNewAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return operations.BeginNewAsync(serviceKey, vnetName, CancellationToken.None);
        }
        
        /// <summary>
        /// The Remove Dedicated Circuit Link operation deletes an existing
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. Service key representing the dedicated circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static ExpressRouteOperationResponse BeginRemove(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).BeginRemoveAsync(serviceKey, vnetName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The Remove Dedicated Circuit Link operation deletes an existing
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. Service key representing the dedicated circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// A standard service response including an HTTP status code and
        /// request ID.
        /// </returns>
        public static Task<ExpressRouteOperationResponse> BeginRemoveAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return operations.BeginRemoveAsync(serviceKey, vnetName, CancellationToken.None);
        }
        
        /// <summary>
        /// The Get Dedicated Circuit Link operation retrieves the specified
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. The service key representing the circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The Get Dedicated Circuit Link operation response.
        /// </returns>
        public static DedicatedCircuitLinkGetResponse Get(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).GetAsync(serviceKey, vnetName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The Get Dedicated Circuit Link operation retrieves the specified
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. The service key representing the circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The Get Dedicated Circuit Link operation response.
        /// </returns>
        public static Task<DedicatedCircuitLinkGetResponse> GetAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return operations.GetAsync(serviceKey, vnetName, CancellationToken.None);
        }
        
        /// <summary>
        /// The Get Express Route operation status gets information on the
        /// status of Express Route operations in Windows Azure.  (see
        /// http://msdn.microsoft.com/en-us/library/windowsazure/jj154112.aspx
        /// for more information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='operationId'>
        /// Required. The id  of the operation.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static ExpressRouteOperationStatusResponse GetOperationStatus(this IDedicatedCircuitLinkOperations operations, string operationId)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).GetOperationStatusAsync(operationId);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The Get Express Route operation status gets information on the
        /// status of Express Route operations in Windows Azure.  (see
        /// http://msdn.microsoft.com/en-us/library/windowsazure/jj154112.aspx
        /// for more information)
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='operationId'>
        /// Required. The id  of the operation.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static Task<ExpressRouteOperationStatusResponse> GetOperationStatusAsync(this IDedicatedCircuitLinkOperations operations, string operationId)
        {
            return operations.GetOperationStatusAsync(operationId, CancellationToken.None);
        }
        
        /// <summary>
        /// The List Dedicated Circuit Links operation retrieves a list of
        /// Vnets that are linked to the circuit with the specified service
        /// key.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Optional.
        /// </param>
        /// <returns>
        /// The List Dedicated Circuit Link operation response.
        /// </returns>
        public static DedicatedCircuitLinkListResponse List(this IDedicatedCircuitLinkOperations operations, string serviceKey)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).ListAsync(serviceKey);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The List Dedicated Circuit Links operation retrieves a list of
        /// Vnets that are linked to the circuit with the specified service
        /// key.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Optional.
        /// </param>
        /// <returns>
        /// The List Dedicated Circuit Link operation response.
        /// </returns>
        public static Task<DedicatedCircuitLinkListResponse> ListAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey)
        {
            return operations.ListAsync(serviceKey, CancellationToken.None);
        }
        
        /// <summary>
        /// The New Dedicated Circuit Link operation creates a new dedicated
        /// circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static ExpressRouteOperationStatusResponse New(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).NewAsync(serviceKey, vnetName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The New Dedicated Circuit Link operation creates a new dedicated
        /// circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static Task<ExpressRouteOperationStatusResponse> NewAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return operations.NewAsync(serviceKey, vnetName, CancellationToken.None);
        }
        
        /// <summary>
        /// The Remove Dedicated Circuit Link operation deletes an existing
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. Service Key associated with the dedicated circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static ExpressRouteOperationStatusResponse Remove(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return Task.Factory.StartNew((object s) => 
            {
                return ((IDedicatedCircuitLinkOperations)s).RemoveAsync(serviceKey, vnetName);
            }
            , operations, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default).Unwrap().GetAwaiter().GetResult();
        }
        
        /// <summary>
        /// The Remove Dedicated Circuit Link operation deletes an existing
        /// dedicated circuit link.
        /// </summary>
        /// <param name='operations'>
        /// Reference to the
        /// Microsoft.WindowsAzure.Management.ExpressRoute.IDedicatedCircuitLinkOperations.
        /// </param>
        /// <param name='serviceKey'>
        /// Required. Service Key associated with the dedicated circuit.
        /// </param>
        /// <param name='vnetName'>
        /// Required.
        /// </param>
        /// <returns>
        /// The response body contains the status of the specified asynchronous
        /// operation, indicating whether it has succeeded, is inprogress, or
        /// has failed. Note that this status is distinct from the HTTP status
        /// code returned for the Get Operation Status operation itself.  If
        /// the asynchronous operation succeeded, the response body includes
        /// the HTTP status code for the successful request.  If the
        /// asynchronous operation failed, the response body includes the HTTP
        /// status code for the failed request, and also includes error
        /// information regarding the failure.
        /// </returns>
        public static Task<ExpressRouteOperationStatusResponse> RemoveAsync(this IDedicatedCircuitLinkOperations operations, string serviceKey, string vnetName)
        {
            return operations.RemoveAsync(serviceKey, vnetName, CancellationToken.None);
        }
    }
}
